#AI智慧漫画项目

#数据范式设计

设定要求 您是一名专业的数据库工程师，熟悉PostgreSQL和ParseServer。 请注意表名用大驼峰，字段小驼峰。 有预留字段：objectId、updatedAt、createdAt。 关于ParseServer中数据类的描述，字段的主要类型有：
String => String 
Number => Number 
Bool => bool 
Array => JSON Array 
Object => JSON Object 
Date => Date 
File => Parse.File 
Pointer => other Parse.Object // 指针类型的字段不需要用xxxId形式命名，直接写xxx即可。 
Relation => Parse.Relation 
Null => null 
GeoPoint => {latitude: 40.0, longitude: -30.0}
项目需求 AI智慧漫画的辅助AI应用，用户（_User）、漫画计划、漫画任务，请您根据漫画指导、任务代办的应用经验，设计以上三张表，用直接用预留的_User表即可。

输出结果（UML类图） 请您帮我用plantuml的类图描述设计好的几张表及其关系

输出结果（信息结构图） 请您帮我用markmap格式表示上面的信息结构图

输出结果（SQL语句） 请您帮我用sql格式给我建表语句和测试数据插入语句，注意字段请使用小驼峰用""引起来。

#UML类图
```plantuml
@startuml
' 设置类图方向
left to right direction
skinparam groupInheritance 2

' 内置用户表（已存在）
class _User {
  + objectId: String <<PK>>
  + username: String
  + email: String
  + password: String
  + authData: Object
  + emailVerified: bool
  + createdAt: Date
  + updatedAt: Date
}

' 漫画计划表
class ComicPlan {
  + objectId: String <<PK>>
  + planName: String
  + description: String
  + coverImage: Parse.File
  + totalTasks: Number
  + completedTasks: Number
  + status: String <<"draft | active | completed | archived">>
  + difficulty: String <<"beginner | intermediate | advanced">>
  + tags: Array<String>
  + creator: Pointer<_User>
  + dueDate: Date
  + createdAt: Date
  + updatedAt: Date
}

' 漫画任务表
class ComicTask {
  + objectId: String <<PK>>
  + taskName: String
  + description: String
  + step: Number <<任务步骤序号>>
  + type: String <<"storyboard | sketch | lineart | coloring | lettering | review">>
  + referenceImages: Array<Parse.File>
  + aiFeedback: Object <<AI生成的反馈数据>>
  + isCompleted: bool
  + priority: Number <<1-5>>
  + estimatedHours: Number
  + actualHours: Number
  + plan: Pointer<ComicPlan>
  + assignee: Pointer<_User>
  + startDate: Date
  + endDate: Date
  + createdAt: Date
  + updatedAt: Date
}

' 关系定义
_User "1" -- "n" ComicPlan : creates >
_User "1" -- "n" ComicTask : assigned >
ComicPlan "1" -- "n" ComicTask : contains >

' 注释说明
note top of ComicPlan
  计划状态说明：
  - draft: 草稿
  - active: 进行中
  - completed: 已完成
  - archived: 已归档
end note

note right of ComicTask
  任务类型说明：
  - storyboard: 分镜设计
  - sketch: 草图绘制
  - lineart: 线稿
  - coloring: 上色
  - lettering: 文字添加
  - review: 审核
end note

@enduml
```